@@ -53,7 +53,7 @@
 #include <QPainter>
 #include <QWhatsThis>
 #include <QWindow>
-#include <QtDBus/QtDBus>
+#include <QDBusConnection>
 #include <QPlatformSurfaceEvent>
 
 #if HAVE_X11
@@ -72,27 +72,31 @@
 
 
 MainWindow::MainWindow(QWidget* parent)
-    : QMainWindow(parent, Qt::CustomizeWindowHint | Qt::FramelessWindowHint)
+    : KMainWindow(parent, Qt::CustomizeWindowHint | Qt::FramelessWindowHint)
 {
     QDBusConnection::sessionBus().registerObject(QStringLiteral("/yakuake/window"), this, QDBusConnection::ExportScriptableSlots);
 
     setAttribute(Qt::WA_TranslucentBackground, true);
+    setAttribute(Qt::WA_DeleteOnClose, false);
+    setAttribute(Qt::WA_QuitOnClose, true);
 
     m_skin = new Skin();
     m_menu = new QMenu(this);
     m_helpMenu = new KHelpMenu(this, KAboutData::applicationData());
     m_sessionStack = new SessionStack(this);
-    m_tabBar = new TabBar(this);
     m_titleBar = new TitleBar(this);
+    m_tabBar = new TabBar(this);
+
     m_firstRunDialog = NULL;
+    m_isFullscreen = false;
 
 #if HAVE_X11
     m_kwinAssistPropSet = false;
-    m_isX11 = QX11Info::isPlatformX11();
+    m_isX11 = KWindowSystem::isPlatformX11();
 #else
     m_isX11 = false;
 #endif
-    m_isWayland = QGuiApplication::platformName().startsWith(QLatin1String("wayland"));
+    m_isWayland = KWindowSystem::isPlatformWayland();
 #if HAVE_KWAYLAND
     m_plasmaShell = Q_NULLPTR;
     m_plasmaShellSurface = Q_NULLPTR;
@@ -222,10 +226,7 @@ bool MainWindow::queryClose()
             warningMessage + QStringLiteral("<br /><br />") + closeQuestion,
             xi18nc("@title:window", "Really Quit?"), KStandardGuiItem::quit(), KStandardGuiItem::cancel());
 
-        if (result == KMessageBox::Continue)
-            return true;
-        else
-            return false;
+        return result != KMessageBox::Cancel;
     }
 
     return true;
@@ -237,12 +238,12 @@ void MainWindow::setupActions()
 
     KToggleFullScreenAction* fullScreenAction = new KToggleFullScreenAction(this);
     fullScreenAction->setWindow(this);
-    fullScreenAction->setShortcut(QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_F11));
+    actionCollection()->setDefaultShortcut(fullScreenAction, QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_F11));
     m_actionCollection->addAction(QStringLiteral("view-full-screen"), fullScreenAction);
     connect(fullScreenAction, SIGNAL(toggled(bool)), this, SLOT(setFullScreen(bool)));
 
     QAction* action = KStandardAction::quit(this, SLOT(close()), actionCollection());
-    action->setShortcut(QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_Q));
+    actionCollection()->setDefaultShortcut(action, QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_Q));
     action = KStandardAction::aboutApp(m_helpMenu, SLOT(aboutApplication()), actionCollection());
     action = KStandardAction::reportBug(m_helpMenu, SLOT(reportBug()), actionCollection());
     action = KStandardAction::aboutKDE(m_helpMenu, SLOT(aboutKDE()), actionCollection());
@@ -254,7 +255,7 @@ void MainWindow::setupActions()
 
     action = actionCollection()->addAction(QStringLiteral("toggle-window-state"));
     action->setText(xi18nc("@action", "Open/Retract Yakuake"));
-    action->setIcon(QIcon(QStringLiteral("yakuake")));
+    action->setIcon(QIcon::fromTheme(QStringLiteral("yakuake")));
 #ifndef Q_OS_WIN /* PORT */
     KGlobalAccel::self()->setGlobalShortcut(action, QList<QKeySequence>() << QKeySequence(Qt::Key_F12));
 #else
@@ -269,154 +270,154 @@ void MainWindow::setupActions()
 
     action = actionCollection()->addAction(QStringLiteral("manage-profiles"));
     action->setText(xi18nc("@action", "Manage Profiles..."));
-    action->setIcon(QIcon(QStringLiteral("configure")));
+    action->setIcon(QIcon::fromTheme(QStringLiteral("configure")));
     connect(action, SIGNAL(triggered()), m_sessionStack, SIGNAL(manageProfiles()));
 
     action = actionCollection()->addAction(QStringLiteral("edit-profile"));
     action->setText(xi18nc("@action", "Edit Current Profile..."));
-    action->setIcon(QIcon(QStringLiteral("document-properties")));
+    action->setIcon(QIcon::fromTheme(QStringLiteral("document-properties")));
     connect(action, SIGNAL(triggered()), this, SLOT(handleContextDependentAction()));
     m_contextDependentActions << action;
 
     action = actionCollection()->addAction(QStringLiteral("increase-window-width"));
     action->setText(xi18nc("@action", "Increase Window Width"));
-    action->setShortcut(QKeySequence(Qt::ALT + Qt::SHIFT + Qt::Key_Right));
+    actionCollection()->setDefaultShortcut(action, QKeySequence(Qt::ALT + Qt::SHIFT + Qt::Key_Right));
     connect(action, SIGNAL(triggered()), this, SLOT(increaseWindowWidth()));
 
     action = actionCollection()->addAction(QStringLiteral("decrease-window-width"));
     action->setText(xi18nc("@action", "Decrease Window Width"));
-    action->setShortcut(QKeySequence(Qt::ALT + Qt::SHIFT + Qt::Key_Left));
+    actionCollection()->setDefaultShortcut(action, QKeySequence(Qt::ALT + Qt::SHIFT + Qt::Key_Left));
     connect(action, SIGNAL(triggered()), this, SLOT(decreaseWindowWidth()));
 
     action = actionCollection()->addAction(QStringLiteral("increase-window-height"));
     action->setText(xi18nc("@action", "Increase Window Height"));
-    action->setShortcut(QKeySequence(Qt::ALT + Qt::SHIFT + Qt::Key_Down));
+    actionCollection()->setDefaultShortcut(action, QKeySequence(Qt::ALT + Qt::SHIFT + Qt::Key_Down));
     connect(action, SIGNAL(triggered()), this, SLOT(increaseWindowHeight()));
 
     action = actionCollection()->addAction(QStringLiteral("decrease-window-height"));
     action->setText(xi18nc("@action", "Decrease Window Height"));
-    action->setShortcut(QKeySequence(Qt::ALT + Qt::SHIFT + Qt::Key_Up));
+    actionCollection()->setDefaultShortcut(action, QKeySequence(Qt::ALT + Qt::SHIFT + Qt::Key_Up));
     connect(action, SIGNAL(triggered()), this, SLOT(decreaseWindowHeight()));
 
     action = actionCollection()->addAction(QStringLiteral("new-session"));
     action->setText(xi18nc("@action", "New Session"));
-    action->setIcon(QIcon(QStringLiteral("tab-new")));
-    action->setShortcut(QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_T));
+    action->setIcon(QIcon::fromTheme(QStringLiteral("tab-new")));
+    actionCollection()->setDefaultShortcut(action, QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_T));
     connect(action, SIGNAL(triggered()), m_sessionStack, SLOT(addSession()));
 
     action = actionCollection()->addAction(QStringLiteral("new-session-two-horizontal"));
     action->setText(xi18nc("@action", "Two Terminals, Horizontally"));
-    action->setIcon(QIcon(QStringLiteral("tab-new")));
+    action->setIcon(QIcon::fromTheme(QStringLiteral("tab-new")));
     connect(action, SIGNAL(triggered()), m_sessionStack, SLOT(addSessionTwoHorizontal()));
 
     action = actionCollection()->addAction(QStringLiteral("new-session-two-vertical"));
     action->setText(xi18nc("@action", "Two Terminals, Vertically"));
-    action->setIcon(QIcon(QStringLiteral("tab-new")));
+    action->setIcon(QIcon::fromTheme(QStringLiteral("tab-new")));
     connect(action, SIGNAL(triggered()), m_sessionStack, SLOT(addSessionTwoVertical()));
 
     action = actionCollection()->addAction(QStringLiteral("new-session-quad"));
     action->setText(xi18nc("@action", "Four Terminals, Grid"));
-    action->setIcon(QIcon(QStringLiteral("tab-new")));
+    action->setIcon(QIcon::fromTheme(QStringLiteral("tab-new")));
     connect(action, SIGNAL(triggered()), m_sessionStack, SLOT(addSessionQuad()));
 
     action = actionCollection()->addAction(QStringLiteral("close-session"));
     action->setText(xi18nc("@action", "Close Session"));
-    action->setIcon(QIcon(QStringLiteral("tab-close")));
-    action->setShortcut(QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_W));
+    action->setIcon(QIcon::fromTheme(QStringLiteral("tab-close")));
+    actionCollection()->setDefaultShortcut(action, QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_W));
     connect(action, SIGNAL(triggered()), this, SLOT(handleContextDependentAction()));
     m_contextDependentActions << action;
 
     action = actionCollection()->addAction(QStringLiteral("previous-session"));
     action->setText(xi18nc("@action", "Previous Session"));
-    action->setIcon(QIcon(QStringLiteral("go-previous")));
-    action->setShortcut(QKeySequence(Qt::SHIFT + Qt::Key_Left));
+    action->setIcon(QIcon::fromTheme(QStringLiteral("go-previous")));
+    actionCollection()->setDefaultShortcut(action, QKeySequence(Qt::SHIFT + Qt::Key_Left));
     connect(action, SIGNAL(triggered()), m_tabBar, SLOT(selectPreviousTab()));
 
     action = actionCollection()->addAction(QStringLiteral("next-session"));
     action->setText(xi18nc("@action", "Next Session"));
-    action->setIcon(QIcon(QStringLiteral("go-next")));
-    action->setShortcut(QKeySequence(Qt::SHIFT + Qt::Key_Right));
+    action->setIcon(QIcon::fromTheme(QStringLiteral("go-next")));
+    actionCollection()->setDefaultShortcut(action, QKeySequence(Qt::SHIFT + Qt::Key_Right));
     connect(action, SIGNAL(triggered()), m_tabBar, SLOT(selectNextTab()));
 
     action = actionCollection()->addAction(QStringLiteral("move-session-left"));
     action->setText(xi18nc("@action", "Move Session Left"));
-    action->setIcon(QIcon(QStringLiteral("arrow-left")));
-    action->setShortcut(QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_Left));
+    action->setIcon(QIcon::fromTheme(QStringLiteral("arrow-left")));
+    actionCollection()->setDefaultShortcut(action, QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_Left));
     connect(action, SIGNAL(triggered()), this, SLOT(handleContextDependentAction()));
     m_contextDependentActions << action;
 
     action = actionCollection()->addAction(QStringLiteral("move-session-right"));
     action->setText(xi18nc("@action", "Move Session Right"));
-    action->setIcon(QIcon(QStringLiteral("arrow-right")));
-    action->setShortcut(QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_Right));
+    action->setIcon(QIcon::fromTheme(QStringLiteral("arrow-right")));
+    actionCollection()->setDefaultShortcut(action, QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_Right));
     connect(action, SIGNAL(triggered()), this, SLOT(handleContextDependentAction()));
     m_contextDependentActions << action;
 
     action = actionCollection()->addAction(QStringLiteral("grow-terminal-right"));
     action->setText(xi18nc("@action", "Grow Terminal to the Right"));
-    action->setIcon(QIcon(QStringLiteral("arrow-right")));
-    action->setShortcut(QKeySequence(Qt::CTRL + Qt::ALT + Qt::Key_Right));
+    action->setIcon(QIcon::fromTheme(QStringLiteral("arrow-right")));
+    actionCollection()->setDefaultShortcut(action, QKeySequence(Qt::CTRL + Qt::ALT + Qt::Key_Right));
     connect(action, SIGNAL(triggered()), this, SLOT(handleContextDependentAction()));
     m_contextDependentActions << action;
 
     action = actionCollection()->addAction(QStringLiteral("grow-terminal-left"));
     action->setText(xi18nc("@action", "Grow Terminal to the Left"));
-    action->setIcon(QIcon(QStringLiteral("arrow-left")));
-    action->setShortcut(QKeySequence(Qt::CTRL + Qt::ALT + Qt::Key_Left));
+    action->setIcon(QIcon::fromTheme(QStringLiteral("arrow-left")));
+    actionCollection()->setDefaultShortcut(action, QKeySequence(Qt::CTRL + Qt::ALT + Qt::Key_Left));
     connect(action, SIGNAL(triggered()), this, SLOT(handleContextDependentAction()));
     m_contextDependentActions << action;
 
     action = actionCollection()->addAction(QStringLiteral("grow-terminal-top"));
     action->setText(xi18nc("@action", "Grow Terminal to the Top"));
-    action->setIcon(QIcon(QStringLiteral("arrow-up")));
-    action->setShortcut(QKeySequence(Qt::CTRL + Qt::ALT + Qt::Key_Up));
+    action->setIcon(QIcon::fromTheme(QStringLiteral("arrow-up")));
+    actionCollection()->setDefaultShortcut(action, QKeySequence(Qt::CTRL + Qt::ALT + Qt::Key_Up));
     connect(action, SIGNAL(triggered()), this, SLOT(handleContextDependentAction()));
     m_contextDependentActions << action;
 
     action = actionCollection()->addAction(QStringLiteral("grow-terminal-bottom"));
     action->setText(xi18nc("@action", "Grow Terminal to the Bottom"));
-    action->setIcon(QIcon(QStringLiteral("arrow-down")));
-    action->setShortcut(QKeySequence(Qt::CTRL + Qt::ALT + Qt::Key_Down));
+    action->setIcon(QIcon::fromTheme(QStringLiteral("arrow-down")));
+    actionCollection()->setDefaultShortcut(action, QKeySequence(Qt::CTRL + Qt::ALT + Qt::Key_Down));
     connect(action, SIGNAL(triggered()), this, SLOT(handleContextDependentAction()));
     m_contextDependentActions << action;
 
     action = actionCollection()->addAction(QStringLiteral("rename-session"));
     action->setText(xi18nc("@action", "Rename Session..."));
-    action->setIcon(QIcon(QStringLiteral("edit-rename")));
-    action->setShortcut(QKeySequence(Qt::CTRL + Qt::ALT + Qt::Key_S));
+    action->setIcon(QIcon::fromTheme(QStringLiteral("edit-rename")));
+    actionCollection()->setDefaultShortcut(action, QKeySequence(Qt::CTRL + Qt::ALT + Qt::Key_S));
     connect(action, SIGNAL(triggered()), this, SLOT(handleContextDependentAction()));
     m_contextDependentActions << action;
 
     action = actionCollection()->addAction(QStringLiteral("previous-terminal"));
     action->setText(xi18nc("@action", "Previous Terminal"));
-    action->setIcon(QIcon(QStringLiteral("go-previous")));
-    action->setShortcut(QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_Up));
+    action->setIcon(QIcon::fromTheme(QStringLiteral("go-previous")));
+    actionCollection()->setDefaultShortcut(action, QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_Up));
     connect(action, SIGNAL(triggered()), m_sessionStack, SIGNAL(previousTerminal()));
 
     action = actionCollection()->addAction(QStringLiteral("next-terminal"));
     action->setText(xi18nc("@action", "Next Terminal"));
-    action->setIcon(QIcon(QStringLiteral("go-next")));
-    action->setShortcut(QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_Down));
+    action->setIcon(QIcon::fromTheme(QStringLiteral("go-next")));
+    actionCollection()->setDefaultShortcut(action, QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_Down));
     connect(action, SIGNAL(triggered()), m_sessionStack, SIGNAL(nextTerminal()));
 
     action = actionCollection()->addAction(QStringLiteral("close-active-terminal"));
     action->setText(xi18nc("@action", "Close Active Terminal"));
-    action->setIcon(QIcon(QStringLiteral("view-close")));
-    action->setShortcut(QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_R));
+    action->setIcon(QIcon::fromTheme(QStringLiteral("view-close")));
+    actionCollection()->setDefaultShortcut(action, QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_R));
     connect(action, SIGNAL(triggered()), this, SLOT(handleContextDependentAction()));
     m_contextDependentActions << action;
 
     action = actionCollection()->addAction(QStringLiteral("split-left-right"));
     action->setText(xi18nc("@action", "Split Left/Right"));
-    action->setIcon(QIcon(QStringLiteral("view-split-left-right")));
-    action->setShortcut(QKeySequence(Qt::CTRL+ Qt::Key_ParenLeft));
+    action->setIcon(QIcon::fromTheme(QStringLiteral("view-split-left-right")));
+    actionCollection()->setDefaultShortcut(action, QKeySequence(Qt::CTRL+ Qt::Key_ParenLeft));
     connect(action, SIGNAL(triggered()), this, SLOT(handleContextDependentAction()));
     m_contextDependentActions << action;
 
     action = actionCollection()->addAction(QStringLiteral("split-top-bottom"));
     action->setText(xi18nc("@action", "Split Top/Bottom"));
-    action->setIcon(QIcon(QStringLiteral("view-split-top-bottom")));
-    action->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_ParenRight));
+    action->setIcon(QIcon::fromTheme(QStringLiteral("view-split-top-bottom")));
+    actionCollection()->setDefaultShortcut(action, QKeySequence(Qt::CTRL + Qt::Key_ParenRight));
     connect(action, SIGNAL(triggered()), this, SLOT(handleContextDependentAction()));
     m_contextDependentActions << action;
 
@@ -434,14 +435,14 @@ void MainWindow::setupActions()
 
     action = actionCollection()->addAction(QStringLiteral("toggle-session-monitor-activity"));
     action->setText(xi18nc("@action", "Monitor for Activity"));
-    action->setShortcut(QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_A));
+    actionCollection()->setDefaultShortcut(action, QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_A));
     action->setCheckable(true);
     connect(action, SIGNAL(triggered(bool)), this, SLOT(handleContextDependentToggleAction(bool)));
     m_contextDependentActions << action;
 
     action = actionCollection()->addAction(QStringLiteral("toggle-session-monitor-silence"));
     action->setText(xi18nc("@action", "Monitor for Silence"));
-    action->setShortcut(QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_I));
+    actionCollection()->setDefaultShortcut(action, QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_I));
     action->setCheckable(true);
     connect(action, SIGNAL(triggered(bool)), this, SLOT(handleContextDependentToggleAction(bool)));
     m_contextDependentActions << action;
@@ -649,6 +650,9 @@ void MainWindow::setupMenu()
     m_menu->addAction(actionCollection()->action(QLatin1String(KStandardAction::name(KStandardAction::KeyBindings))));
     m_menu->addAction(actionCollection()->action(QLatin1String(KStandardAction::name(KStandardAction::ConfigureNotifications))));
     m_menu->addAction(actionCollection()->action(QLatin1String(KStandardAction::name(KStandardAction::Preferences))));
+
+    m_menu->addSeparator();
+    m_menu->addAction(actionCollection()->action(QLatin1String(KStandardAction::name(KStandardAction::Quit))));
 }
 
 void MainWindow::updateScreenMenu()
@@ -749,6 +753,7 @@ void MainWindow::configureApp()
     if (KConfigDialog::showDialog(QStringLiteral("settings"))) return;
 
     KConfigDialog* settingsDialog = new KConfigDialog(this, QStringLiteral("settings"), Settings::self());
+    settingsDialog->setMinimumHeight(560);
     settingsDialog->setFaceType(KPageDialog::List);
     connect(settingsDialog, &KConfigDialog::settingsChanged, this, &MainWindow::applySettings);
 
@@ -846,6 +851,7 @@ void MainWindow::applyWindowProperties()
         KWindowSystem::setState(winId(), NET::KeepAbove | NET::Sticky | NET::SkipTaskbar | NET::SkipPager);
 
     KWindowSystem::setOnAllDesktops(winId(), Settings::showOnAllDesktops());
+    KWindowEffects::enableBlurBehind(winId(), Settings::blur());
 }
 
 void MainWindow::applyWindowGeometry()
@@ -893,9 +899,17 @@ void MainWindow::setWindowGeometry(int newWidth, int newHeight, int newPosition)
 
     if (Settings::showTabBar())
     {
-        maxHeight -= m_tabBar->height();
-        m_tabBar->setGeometry(m_skin->borderWidth(), maxHeight,
-            width() - 2 * m_skin->borderWidth(), m_tabBar->height());
+        if (m_skin->tabBarCompact())
+        {
+            m_tabBar->setGeometry(m_skin->tabBarLeft(), maxHeight,
+                width() - m_skin->tabBarLeft() - m_skin->tabBarRight(), m_tabBar->height());
+        }
+        else
+        {
+            maxHeight -= m_tabBar->height();
+            m_tabBar->setGeometry(m_skin->borderWidth(), maxHeight,
+                width() - 2 * m_skin->borderWidth(), m_tabBar->height());
+        }
     }
 
     m_sessionStack->setGeometry(m_skin->borderWidth(), 0,
@@ -995,7 +1009,7 @@ void MainWindow::paintEvent(QPaintEvent* event)
         height() - m_titleBar->height());
     painter.fillRect(rightBorder, m_skin->borderColor());
 
-    QMainWindow::paintEvent(event);
+    KMainWindow::paintEvent(event);
 }
 
 void MainWindow::moveEvent(QMoveEvent* event)
@@ -1009,7 +1023,15 @@ void MainWindow::moveEvent(QMoveEvent* event)
         applyWindowGeometry();
     }
 
-    QMainWindow::moveEvent(event);
+    KMainWindow::moveEvent(event);
+}
+
+void MainWindow::closeEvent(QCloseEvent *event)
+{
+    KMainWindow::closeEvent(event);
+    if (event->isAccepted()) {
+        QApplication::quit();
+    }
 }
 
 void MainWindow::wmActiveWindowChanged()
@@ -1053,7 +1075,7 @@ void MainWindow::changeEvent(QEvent* event)
         updateWindowHeightMenu();
     }
 
-    QMainWindow::changeEvent(event);
+    KMainWindow::changeEvent(event);
 }
 
 bool MainWindow::event(QEvent* event)
@@ -1072,7 +1094,7 @@ bool MainWindow::event(QEvent* event)
 #endif
     }
 
-    return QMainWindow::event(event);
+    return KMainWindow::event(event);
 }
 
 void MainWindow::toggleWindowState()
@@ -1100,11 +1122,11 @@ void MainWindow::toggleWindowState()
         else if (!Settings::showOnAllDesktops()
                  &&  KWindowInfo(winId(), NET::WMDesktop).desktop() != KWindowSystem::currentDesktop())
         {
-            // The open/restract action isn't set to focus the window, but
+            // The open/restrict action isn't set to focus the window, but
             // the window is currently on another virtual desktop (the option
             // to show it on all of them is disabled), so closing it doesn't
-            // make sense and we're opting to show it instead to avoid re-
-            // quiring the user to invoke the action twice to get to see
+            // make sense and we're opting to show it instead to avoid
+            // requiring the user to invoke the action twice to get to see
             // Yakuake. Just forcing focus would cause the window manager to
             // switch to the virtual desktop the window currently resides on,
             // so move the window to the current desktop before doing so.
@@ -1311,6 +1333,7 @@ void MainWindow::sharedPreOpenWindow()
     updateUseTranslucency();
 
     if (Settings::pollMouse()) toggleMousePoll(false);
+    if (Settings::rememberFullscreen()) setFullScreen(m_isFullscreen);
 }
 
 void MainWindow::sharedAfterOpenWindow()
@@ -1388,6 +1411,7 @@ void MainWindow::setKeepOpen(bool keepOpen)
 
 void MainWindow::setFullScreen(bool state)
 {
+    if (isVisible()) m_isFullscreen = state;
     if (state)
     {
         setWindowState(windowState() | Qt::WindowFullScreen);
